@@ -1,4 +1,5 @@
 from unittest import TestCase
+from decimal import Decimal
 import datetime
 import sys
 
@@ -15,8 +16,8 @@ class TestType(TestCase):
     def test_schema(self):
         schema = {
             "type": [
-                { "type": "array", "minItems": 10 },
-                { "type": "string", "pattern": "^0+$" }
+                {"type": "array", "minItems": 10},
+                {"type": "string", "pattern": "^0+$"}
             ]
         }
 
@@ -35,62 +36,56 @@ class TestType(TestCase):
     def _test_type(self, typename, valids, invalids):
         for x in valids:
             try:
-                validictory.validate(x, {"type":typename})
+                validictory.validate(x, {"type": typename})
             except ValueError as e:
                 self.fail("Unexpected failure: %s" % e)
 
         for x in invalids:
             self.assertRaises(ValueError, validictory.validate, x,
-                              {"type":typename})
+                              {"type": typename})
 
     def test_integer(self):
         valid_ints = [1, -89, 420000]
-        invalid_ints = [1.2, "bad", {"test":"blah"}, [32, 49], None, True]
+        invalid_ints = [1.2, "bad", {"test": "blah"}, [32, 49], None, True]
         self._test_type('integer', valid_ints, invalid_ints)
 
     def test_string(self):
         valids = ["abc", unicode_str]
-        invalids = [1.2, 1, {"test":"blah"}, [32, 49], None, True]
+        invalids = [1.2, 1, {"test": "blah"}, [32, 49], None, True]
         self._test_type('string', valids, invalids)
 
     def test_number(self):
-        valids = [1.2, -89.42, 48, -32]
-        invalids = ["bad", {"test":"blah"}, [32.42, 494242], None, True]
+        valids = [1.2, -89.42, 48, -32, Decimal('25.25')]
+        invalids = ["bad", {"test": "blah"}, [32.42, 494242], None, True]
         self._test_type('number', valids, invalids)
 
     def test_boolean(self):
         valids = [True, False]
-        invalids = [1.2, "False", {"test":"blah"}, [32, 49], None, 1, 0]
+        invalids = [1.2, "False", {"test": "blah"}, [32, 49], None, 1, 0]
         self._test_type('boolean', valids, invalids)
 
     def test_object(self):
-        valids = [{"blah": "test"}, {"this":{"blah":"test"}}, {1:2, 10:20}]
+        valids = [{"blah": "test"}, {"this": {"blah": "test"}}, {1: 2, 10: 20}]
         invalids = [1.2, "bad", 123, [32, 49], None, True]
         self._test_type('object', valids, invalids)
 
     def test_array(self):
-        valids = [[1, 89], [48, {"test":"blah"}, "49", 42], (47, 11)]
-        invalids = [1.2, "bad", {"test":"blah"}, 1234, None, True]
+        valids = [[1, 89], [48, {"test": "blah"}, "49", 42], (47, 11)]
+        invalids = [1.2, "bad", {"test": "blah"}, 1234, None, True]
         self._test_type('array', valids, invalids)
 
     def test_null(self):
         valids = [None]
-        invalids = [1.2, "bad", {"test":"blah"}, [32, 49], 1284, True]
+        invalids = [1.2, "bad", {"test": "blah"}, [32, 49], 1284, True]
         self._test_type('null', valids, invalids)
 
-    def test_ip_address(self):
-        valids = ["0.0.0.0", "255.255.255.255"]
-        invalids = [1.2, "bad", {"test":"blah"}, [32, 49], 1284, True,
-                    "-0.-0.-0.-0", "-1.-1.-1.-1", "256.256.256.256"]
-        self._test_type('ip-address', valids, invalids)
-
     def test_any(self):
-        valids = [1.2, "bad", {"test":"blah"}, [32, 49], None, 1284, True]
+        valids = [1.2, "bad", {"test": "blah"}, [32, 49], None, 1284, True]
         self._test_type('any', valids, [])
 
     def test_default(self):
         # test default value (same as any really)
-        valids = [1.2, "bad", {"test":"blah"}, [32, 49], None, 1284, True]
+        valids = [1.2, "bad", {"test": "blah"}, [32, 49], None, 1284, True]
         for x in valids:
             try:
                 validictory.validate(x, {})
@@ -100,21 +95,22 @@ class TestType(TestCase):
     def test_multi(self):
         types = ["null", "integer", "string"]
         valids = [None, 42, "string"]
-        invalids = [1.2, {"test":"blah"}, [32, 49], True]
+        invalids = [1.2, {"test": "blah"}, [32, 49], True]
         self._test_type(types, valids, invalids)
         self._test_type(tuple(types), valids, invalids)
 
+
 class TestDisallow(TestType):
     def _test_type(self, typename, valids, invalids):
         for x in invalids:
             try:
-                validictory.validate(x, {"disallow":typename})
+                validictory.validate(x, {"disallow": typename})
             except ValueError as e:
                 self.fail("Unexpected failure: %s" % e)
 
         for x in valids:
             self.assertRaises(ValueError, validictory.validate, x,
-                              {"disallow":typename})
+                              {"disallow": typename})
 
 
 class DateValidator(validictory.validator.SchemaValidator):
@@ -144,10 +140,10 @@ class TestCustomType(TestCase):
         validator = DateValidator()
         for x in valids:
             try:
-                validator.validate(x, {"type":typename})
+                validator.validate(x, {"type": typename})
             except ValueError as e:
                 self.fail("Unexpected failure: %s" % e)
 
         for x in invalids:
             self.assertRaises(ValueError, validator.validate, x,
-                              {"type":typename})
+                              {"type": typename})
